/**
 * (c) Atos IT Solutions and Services GmbH, 2011.
 * Licensed under EUPL 1.1
 */
package com.sag.osami.contextstore.storage.impl;

import java.util.Collections;
import java.util.List;

import com.sag.osami.api.context.ContextEvent;
import com.sag.osami.contextstore.serialization.ISerializationHandler;
import com.sag.osami.contextstore.storage.ISerializedContextStorage;

/**
 * A dummy storage implementation which does not store anything and returns <code>null</code> or empty collections as results for loading and querying.
 * 
 */
public class NullStorage implements ISerializedContextStorage {
	@Override
	public ContextEvent load(Long contextId) {
		return null;
	}

	@Override
	public ContextEvent[] load(List<Long> contextIds) {
		return new ContextEvent[0];
	}

	@Override
	public ContextEvent[] query(String query, Object... params) {
		return new ContextEvent[0];
	}

	@Override
	public void store(ContextEvent context) {
		// do nothing
	}

	@Override
	public void delete(Long contextId) {
		// do nothing
	}

	@Override
	public void delete(List<Long> contextIds) {
		// do nothing
	}

	@Override
	public void delete(String query, Object... params) {
		// do nothing
	}

	@Override
	public ContextEvent load(boolean deserialize, Long contextId) {
		return null;
	}

	@Override
	public ContextEvent[] load(boolean deserialize, List<Long> contextIds) {
		return new ContextEvent[0];
	}

	@Override
	public ContextEvent[] query(boolean deserialize, String query, Object... params) {
		return new ContextEvent[0];
	}

	@Override
	public void store(boolean serialize, ContextEvent context) {
		// do nothing
	}

	@Override
	public void setSerializer(ISerializationHandler serializer) {
		// we don't use the serializer
	}

	@Override
	public Long retrieveLastID() {
		return 0L;
	}

	@Override
	public Iterable<ContextEvent> loadLazy(List<Long> contextIds) throws UnsupportedOperationException {
		return Collections.emptyList();
	}

	@Override
	public Iterable<ContextEvent> queryLazy(String query, Object... params) {
		return Collections.emptyList();
	}

	@Override
	public Iterable<ContextEvent> loadLazy(boolean deserialize, List<Long> contextIds) {
		return Collections.emptyList();
	}

	@Override
	public Iterable<ContextEvent> queryLazy(boolean deserialize, String query, Object... params) {
		return Collections.emptyList();
	}
}