/**
 * (c) Atos IT Solutions and Services GmbH, 2011.
 * Licensed under EUPL 1.1
 */
package com.sag.osami.contextstore.util;

import java.util.concurrent.ThreadFactory;
import java.util.concurrent.atomic.AtomicInteger;

/**
 * Thread factory with configurable thread names. A count can be appended to the name.
 */
public class NamedThreadFactory implements ThreadFactory {

	private final String prefix;
	private final AtomicInteger num;

	public NamedThreadFactory(String prefix, boolean doCount) {
		this.prefix = prefix;
		this.num = (doCount) ? new AtomicInteger(1) : null;
	}

	public Thread newThread(Runnable r) {
		String tname = (num == null) ? prefix : prefix + num.getAndIncrement();
		Thread t = new Thread(Thread.currentThread().getThreadGroup(), r, tname, 0);
		if (t.isDaemon())
			t.setDaemon(false);
		if (t.getPriority() != Thread.NORM_PRIORITY)
			t.setPriority(Thread.NORM_PRIORITY);
		return t;
	}
}