/**
 * (c) Atos IT Solutions and Services GmbH, 2011.
 * Licensed under EUPL 1.1
 */
package com.sag.osami.context.eventadminwrapper;

import java.util.ArrayList;
import java.util.Date;
import java.util.Dictionary;
import java.util.Hashtable;

import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceRegistration;
import org.osgi.service.event.Event;
import org.osgi.service.event.EventConstants;
import org.osgi.service.event.EventHandler;
import org.osgi.service.log.LogService;

import com.sag.osami.api.context.ContextEvent;
import com.sag.osami.api.context.IContextHandler;
import com.sag.osami.api.context.IContextStore;
import com.sag.osami.api.context.IOsgiToContextEvent;

/**
 * The OsgiEventToContextEvent service provides a wrapper to wrap standard OSGI
 * Events as ContextEvents.
 */
public class OsgiEventToContextEvent implements BundleActivator, EventHandler, IContextHandler, IOsgiToContextEvent {

	private IContextStore contextStore;
	private LogService log = null;
	private ArrayList<String> topicList;
	private Dictionary<String, Object> events = null;
	private ServiceRegistration sReg = null;
	private BundleContext bundleContext = null;


	public void start(BundleContext bundleContext) throws Exception {

		this.bundleContext = bundleContext;
		this.topicList = new ArrayList<String>();
		this.events = new Hashtable<String, Object>();	
		
		this.log = (LogService) bundleContext.getService(bundleContext.getServiceReference(LogService.class.getName()));

		String[] clazzes = new String[] { IContextHandler.class.getName(), IOsgiToContextEvent.class.getName() };
		bundleContext.registerService(clazzes, this, null);

		this.log.log(LogService.LOG_DEBUG, "Register Service");

	}

	private void updateEventHandler() {
		
		String[] tmp = new String[this.topicList.size()];
//		this.topicList.toArray(tmp);
		for (int i = 0; i < tmp.length; i++) {
			tmp[i] = this.topicList.get(i);			
		}
		
		this.events.remove(EventConstants.EVENT_TOPIC);
		this.events.put(EventConstants.EVENT_TOPIC, tmp);

		if (this.sReg != null) {
			this.sReg.setProperties(this.events);
		} else {
			this.sReg = this.bundleContext.registerService(EventHandler.class.getName(), this, this.events);
		}

	}
	
	public void stop(BundleContext arg0) throws Exception {
		// TODO Auto-generated method stub

	}

	public void handleContextEvent(ContextEvent context) {
		// TODO Auto-generated method stub

	}

	public void addTopic(String topic) {
		if (!this.topicList.contains(topic)) {
			this.topicList.add(topic);
			this.updateEventHandler();
		}

	}

	public void addTopics(String[] topics) {
		for (int i = 0; i < topics.length; i++) {
			if (!this.topicList.contains(topics[i])) {
				this.topicList.add(topics[i]);
			}
		}
		this.updateEventHandler();
	}


	public void removeTopic(String topic) {
		if (!this.topicList.contains(topic)) {
			this.topicList.remove(topic);
		}
		this.updateEventHandler();
	}

	public void removeTopics(String[] topics) {
		for (int i = 0; i < topics.length; i++) {
			if (!this.topicList.contains(topics[i])) {
				this.topicList.remove(topics[i]);
			}
		}
		this.updateEventHandler();
	}

	/**
	 * since it is a wrapper that sends new ContextEvents it has to default
	 * types to handle.
	 */

	
	public String[] getDefaultContextTypes() {
		// TODO Auto-generated method stub
		return null;
	}


	public void handleEvent(Event event) {
		// System.out.println("[Wrapper]" + event);
		log.log(LogService.LOG_INFO, "[Wrapper]" + event);
		if (event.getTopic().equals("org/osgi/service/log/LogEntry/LOG_DEBUG")) {
			log.log(LogService.LOG_INFO, "[Wrapper-LOG]");
		}
		String topic = event.getTopic();
		this.contextStore.newContextEvent(topic, topic, event, new Date());
	}


	public void setContextStore(IContextStore contextStore) {
		this.contextStore = contextStore;

		log.log(LogService.LOG_DEBUG, "Set ContextStore");

	}
}
